# Provisioning SAP LeanIX from SAP for Me (classic)
### On this page
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/workspace-provisioning#prerequisites)
  * [Context](https://help.sap.com/docs/leanix/ea/workspace-provisioning#context)
  * [Procedure](https://help.sap.com/docs/leanix/ea/workspace-provisioning#procedure)
  * [Results](https://help.sap.com/docs/leanix/ea/workspace-provisioning#results-1)


Learn how to provision workspaces in SAP LeanIX using SAP for Me.
